@@ -23,6 +23,7 @@
 #include "kb_qwerty.h"
 #include "dialogabout.h"
 #include "dialogsettings.h"
+
 #include <QCloseEvent>
 #include <QMenuBar>
 
@@ -199,18 +200,21 @@ void FastSMSWidget::loadPreferedKb(QString sOrientation)
     if(sOrientation.length() == 0)
         sOrientation = FastSMSWidget::getDeviceOrientation();
 
+    if(sOrientation.compare("unknown") == 0)
+        return;
+
     if(sOrientation.compare(Core::ORIENTATION_LANDSCAPE))
     {
-        if(settings.value(Core::PREF_LANDSCAPE_KB).toInt() == Core::Qwerty)
+        if(settings.value(Core::PREF_LANDSCAPE_KB,0).toInt() == Core::Qwerty)
             m_layoutManager->enableQwerty();
-        else if(settings.value(Core::PREF_LANDSCAPE_KB).toInt() == Core::Alfanumeric)
+        else if(settings.value(Core::PREF_LANDSCAPE_KB,0).toInt() == Core::Alfanumeric)
             m_layoutManager->enableAlfanum();
     }
     else
     {
-        if(settings.value(Core::PREF_PORTRAIT_KB).toInt() == Core::Qwerty)
+        if(settings.value(Core::PREF_PORTRAIT_KB,1).toInt() == Core::Qwerty)
             m_layoutManager->enableQwerty();
-        else if(settings.value(Core::PREF_PORTRAIT_KB).toInt() == Core::Alfanumeric)
+        else if(settings.value(Core::PREF_PORTRAIT_KB,1).toInt() == Core::Alfanumeric)
             m_layoutManager->enableAlfanum();
     }
 }
@@ -314,23 +318,32 @@ bool FastSMSWidget::addRecipient(const QString &phone, const QString &name)
 
 void FastSMSWidget::insertNewWord()
 {
-    m_dialNewWord = new QDialog(this);
+    m_dialNewWord = new DialogNewWord(this);
     m_dialNewWord->setAttribute(Qt::WA_DeleteOnClose);
-    m_inputNewWord = new QLineEdit(m_dialNewWord);
-    QPushButton *btOk = new QPushButton("Ok",m_dialNewWord);
-    connect(btOk,SIGNAL(clicked()),this,SLOT(newWordInserted()));
-    QGridLayout *insWordLayout = new QGridLayout();
-    insWordLayout->addWidget(m_inputNewWord,0,0);
-    kb_Qwerty *kb = new kb_Qwerty(m_dialNewWord,true);
-    connect(kb,SIGNAL(input(QString,Core::Keyboards)),this,SLOT(composite(QString,Core::Keyboards)));
-    insWordLayout->addWidget(kb,1,0);
-    insWordLayout->addWidget(btOk,2,0);
-    insWordLayout->setContentsMargins(0,0,0,0);
-    m_inputNewWord->setFocus();
+    m_inputNewWord = m_dialNewWord->m_lineEdit;
+    connect(m_dialNewWord->m_btOk,SIGNAL(clicked()),this,SLOT(newWordInserted()));
+    connect(m_dialNewWord->m_kb,SIGNAL(input(QString,Core::Keyboards)),this,SLOT(composite(QString,Core::Keyboards)));
 
-    m_dialNewWord->setWindowTitle("Type new word");
-    m_dialNewWord->setLayout(insWordLayout);
-    m_dialNewWord->showMaximized();
+
+
+//    m_dialNewWord = new QDialog(this);
+//    m_dialNewWord->setAttribute(Qt::WA_DeleteOnClose);
+//    m_inputNewWord = new QLineEdit(m_dialNewWord);
+//    m_inputNewWord->setEnabled(false);
+//    QPushButton *btOk = new QPushButton("Ok",m_dialNewWord);
+//    connect(btOk,SIGNAL(clicked()),this,SLOT(newWordInserted()));
+//    QGridLayout *insWordLayout = new QGridLayout();
+//    insWordLayout->addWidget(m_inputNewWord,0,0);
+//    kb_Qwerty *kb = new kb_Qwerty(m_dialNewWord,true);
+//    connect(kb,SIGNAL(input(QString,Core::Keyboards)),this,SLOT(composite(QString,Core::Keyboards)));
+//    insWordLayout->addWidget(kb,1,0);
+//    insWordLayout->addWidget(btOk,2,0);
+//    insWordLayout->setContentsMargins(0,0,0,0);
+//    m_inputNewWord->setFocus();
+
+//    m_dialNewWord->setWindowTitle("Type new word");
+//    m_dialNewWord->setLayout(insWordLayout);
+    m_dialNewWord->show();
 }
 
 void FastSMSWidget::composite(QString sChar, Core::Keyboards)
