@@ -24,6 +24,7 @@
 #include "dictionary.h"
 #include "layoutmanager.h"
 #include "textprocessor.h"
+#include "dialognewword.h"
 
 namespace Ui {
     class FastSMSWidget;
@@ -62,7 +63,8 @@ private:
     dictionary *m_dictionary;
     LayoutManager *m_layoutManager;
     TextProcessor *m_textProcessor;
-    QDialog *m_dialNewWord;
+    //QDialog *m_dialNewWord;
+    DialogNewWord *m_dialNewWord;
     QLineEdit *m_inputNewWord;
     bool m_bDictionaryUpdated;
     bool m_bStandalone;
