@@ -32,21 +32,21 @@ kb_AlfaNum::kb_AlfaNum(QWidget *parent) :
 
     m_settingsMenu = qobject_cast<SettingsMenu *> (ui->btSettings->menu());
 
-    connect(ui->btOne,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btTwo,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btThree,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btFour,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btFive,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btSix,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btSeven,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btEight,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btNine,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btZero,SIGNAL(clicked()),this, SLOT(inputClicked()));
-    connect(ui->btNext,SIGNAL(clicked()),this, SLOT(nextWordClicked()));
-    connect(ui->btPrev,SIGNAL(clicked()),this, SLOT(prevWordClicked()));
-    connect(ui->btMoveCurNext,SIGNAL(clicked()),this, SLOT(moveRightClicked()));
-    connect(ui->btMoveCurPrev,SIGNAL(clicked()),this, SLOT(moveLeftClicked()));
-    connect(ui->btDelChar,SIGNAL(clicked()),this, SLOT(deleteClicked()));
+    connect(ui->btOne,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btTwo,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btThree,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btFour,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btFive,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btSix,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btSeven,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btEight,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btNine,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btZero,SIGNAL(released()),this, SLOT(inputClicked()));
+    connect(ui->btNext,SIGNAL(released()),this, SLOT(nextWordClicked()));
+    connect(ui->btPrev,SIGNAL(released()),this, SLOT(prevWordClicked()));
+    connect(ui->btMoveCurNext,SIGNAL(released()),this, SLOT(moveRightClicked()));
+    connect(ui->btMoveCurPrev,SIGNAL(released()),this, SLOT(moveLeftClicked()));
+    connect(ui->btDelChar,SIGNAL(released()),this, SLOT(deleteClicked()));
 }
 
 kb_AlfaNum::~kb_AlfaNum()
