@@ -794,10 +794,6 @@ QPushButton* TextProcessor::getSendBt()
 void TextProcessor::commit()
 {
     m_smsEdit->setEnabled(false);
-    //parentWidget()->parentWidget()->hide();
-
-    //wait a moment before commit, so client re-gain focus
-    //sleep(0.8);
 
     QDBusMessage msg = QDBusMessage::createMethodCall(
             "it.rsc.fastsms.plugin.connection", // --dest
@@ -805,77 +801,16 @@ void TextProcessor::commit()
             "it.rsc.fastsms.plugin.connection",
             "requestCommit"
             );
-
-    //msg << "test";
+;
     QList<QVariant> args;
     args.append(m_smsEdit->toPlainText());
     msg.setArguments(args);
     msg = QDBusConnection::sessionBus().call(msg);
-    //qDebug() << msg;
     bool ok = msg.type() != QDBusMessage::ErrorMessage;
 
-    //qDebug() << "Sended:" << msg;
     qDebug() << "Sended:" << ok;
 
-    //Wait for text commit(?)
-    //sleep(2);
-
     //Reset field
     setText("");
-/*
-    //Reset fastwrite state
-    if(!m_bQwertyEnable)
-        m_smsEdit->disconnect();
-
-    m_nState = STATE_SEND;
-    //m_smsEdit->clear();
-    m_sCompleteValue.clear();
-    //m_phoneNumber->clear();
-    m_lWord.clear();
-    m_nWordIndex=0;
-
-    //update char and sms count
-    updateCharCounter(ACTION_SEND);
-
-
-    if(!m_bQwertyEnable)
-    {
-        connect(m_smsEdit,SIGNAL(textChanged()),this,SLOT(smsChanged()));
-        connect(m_smsEdit,SIGNAL(selectionChanged()),this,SLOT(cursorPosChanged()));
-        //Reset FastWrite status
-        processAlfanumeric(Keyboard::DELETE);
-    }*/
 }
 
-//QString TextProcessor::requestCommit()
-//{
-//    QString msg = m_smsEdit->toPlainText();
-//    qDebug() << "msg_1:" << msg;
-
-//    //Reset fastwrite state
-//    if(!m_bQwertyEnable)
-//        m_smsEdit->disconnect();
-
-//    m_nState = STATE_SEND;
-//    m_smsEdit->clear();
-//    m_sCompleteValue.clear();
-//    //m_phoneNumber->clear();
-//    m_lWord.clear();
-//    m_nWordIndex=0;
-
-//    //update char and sms count
-//    updateCharCounter(ACTION_SEND);
-//    //
-
-//    if(!m_bQwertyEnable)
-//    {
-//        connect(m_smsEdit,SIGNAL(textChanged()),this,SLOT(smsChanged()));
-//        connect(m_smsEdit,SIGNAL(selectionChanged()),this,SLOT(cursorPosChanged()));
-//        //Reset FastWrite status
-//        processAlfanumeric(Keyboard::DELETE);
-//    }
-
-//    qDebug() << "msg_2:" << msg;
-//    return msg;
-//}
-
